@@ -26,6 +26,8 @@
  *
  */
 
+#undef GTK_DISABLE_DEPRECATED
+
 #include "config.h"
 
 #include <string.h>
@@ -259,12 +261,12 @@ gpa_transport_selector_file_button_clicked_cb (GtkButton *button, GPATransportSe
 
  
 		filter = gtk_file_filter_new ();
-		gtk_file_filter_set_name (filter, "PDF Files");
+		gtk_file_filter_set_name (filter, _("PDF Files"));
 		gtk_file_filter_add_pattern (filter, "*.pdf");
 		gtk_file_chooser_add_filter (ts->file_selector, filter);
 
 		filter = gtk_file_filter_new ();
-		gtk_file_filter_set_name (filter, "Postscript Files");
+		gtk_file_filter_set_name (filter, _("Postscript Files"));
 		gtk_file_filter_add_pattern (filter, "*.ps");
 		gtk_file_chooser_add_filter (ts->file_selector, filter);
 
